@@ -63,11 +63,11 @@ Evo::Ee
 
 =head1 VERSION
 
-version 0.0208
+version 0.0209
 
 =head1 DESCRIPTION
 
-EventEmitter role for component
+EventEmitter role for Evo classes
 
 =head1 SYNOPSYS
 
@@ -76,8 +76,8 @@ EventEmitter role for component
 
   {
 
-    package My::Comp;
-    use Evo '-Comp *';
+    package My::Class;
+    use Evo '-Class *';
     with '-Ee';
 
     # define available events
@@ -85,7 +85,7 @@ EventEmitter role for component
 
   }
 
-  my $comp = My::Comp::new();
+  my $comp = My::Class::new();
 
   # subscribe on the event
   $comp->on(connection => sub($self, $id) { say "got $id" });
@@ -100,7 +100,7 @@ This role requires method C<ee_events> to be implemented in a derived class. It
   # throws Not recognized event "coNNection"
   $comp->on(coNNection => sub($self, $id) { say "got $id" });
 
-This will prevent people who use your component from the most common mistake in EventEmitter pattern.
+This will prevent people who use your class from the most common mistake in EventEmitter pattern.
 
 =head1 METHODS
 
@@ -110,11 +110,11 @@ Subscbibe
 
   $comp->on(connection => sub($self, @args) { say "$self got: " . join ';', @args });
 
-The name of the event will be checked using C<ee_events>, which should be implemented by component and return a list of available names
+The name of the event will be checked using C<ee_events>, which should be implemented by Evo class and return a list of available names
 
 =head2 emit
 
-Emit an event. The component will be passed to the event as the first argument,  you can provide additional argument to the subscriber
+Emit an event. The object will be passed to the event as the first argument,  you can provide additional argument to the subscriber
 
   $comp->emit(connection => 'arg1', 'arg2');
 
@@ -127,7 +127,7 @@ Add and remove listener from the event by the name and subroutine.
   my $ref = $comp->ee_add(connection => sub {"here"});
   $comp->ee_remove($ref);
 
-The name of the event will be checked using C<ee_events>, which should be implemented by component and return a list of available names
+The name of the event will be checked using C<ee_events>, which should be implemented by class and return a list of available names
 
 Don't use in the event (or weaken ref if you need to use it)
 
