@@ -1,5 +1,5 @@
 package Evo::Eval;
-use Evo '-Export *; :Call';
+use Evo '-Export *; ::Call';
 
 sub eval_want : Export {
   my ($want, $fn) = (shift, pop);
@@ -52,7 +52,7 @@ Evo::Eval
 
 =head1 VERSION
 
-version 0.0208
+version 0.0209
 
 =head1 SYNOPSYS
 
@@ -66,7 +66,7 @@ version 0.0208
   $res = eval_try sub {...}, sub {...};
   $res = eval_try sub {...}, undef, sub {...};
 
-=head1 Comparison with alternatives
+=head1 Classarison with alternatives
 
 =head2 with Try::Tiny
 
