@@ -1,66 +1,34 @@
 package Evo::Export;
-use Evo '-Export::Exporter; Carp croak; -Lib::Bare';
+use Evo '-Attr *; ::Core *';
 
-# + export export_gen export_anon export_proxy export_requires export_hooks
-my @EXPORT = qw( export_install_in MODIFY_CODE_ATTRIBUTES);
-Evo::Export::Exporter::DEFAULT->add_sub(__PACKAGE__, $_) for @EXPORT;
+export_proxy 'Evo::Export::Core', '*';
 
-sub import { export_install_in(scalar caller, @_); }
-
-sub export_install_in ($dst, $src, @list) {
-  Evo::Export::Exporter::DEFAULT->install($src, $dst, @list) if @list;
-}
-
-# pay attention: without provided name all aliases will be found by _find_subnames and exported
-sub MODIFY_CODE_ATTRIBUTES ($pkg, $code, @attrs) {
+sub _attr_handler ($pkg, $code, @attrs) {
   my (@bad, @good);
   foreach my $attr (@attrs) {
     my ($attr_name, $val) = _parse_attr($attr);
     $attr_name eq 'Export' ? push @good, $val : push @bad, $attr;
   }
-  return @bad if @bad;
 
   foreach my $name (@good) {
     my @names = $name ? ($name) : Evo::Lib::Bare::find_subnames($pkg, $code);
-    Evo::Export::Exporter::DEFAULT->add_gen($pkg, $_, sub {$code}) for @names;
+    Evo::Export::Class::DEFAULT->add_gen($pkg, $_, sub {$code}) for @names;
   }
 
-  return;
+
+  return @bad;
 }
 
+
+# pay attention: without provided name all aliases will be found by _find_subnames and exported
+attr_handler \&_attr_handler;
+
 sub _parse_attr($attr) {
   $attr =~ /(\w+) ( \( \s* (\w+) \s* \) )?/x;
   return ($1, $3);
 }
 
 
-sub _add_gen ($name, $gen) {
-  Evo::Export::Exporter::DEFAULT->add_gen(__PACKAGE__, $name, $gen);
-}
-
-_add_gen export_gen => sub($dst) {
-  sub ($name, $gen) {
-    Evo::Export::Exporter::DEFAULT->add_gen($dst, $name, $gen);
-    }
-};
-
-_add_gen export_anon => sub($dst) {
-  sub {
-    my ($name, $fn) = @_;
-    Evo::Export::Exporter::DEFAULT->add_gen($dst, $name, sub {$fn});
-  };
-};
-
-_add_gen export => sub($dst) {
-  sub { Evo::Export::Exporter::DEFAULT->add_sub($dst, $_) for @_ }
-};
-
-_add_gen export_proxy => sub($dst) {
-  sub ($epkg, @list) {
-    Evo::Export::Exporter::DEFAULT->proxy($dst, $epkg, @list);
-    }
-};
-
 1;
 
 __END__
@@ -75,7 +43,7 @@ Evo::Export
 
 =head1 VERSION
 
-version 0.0208
+version 0.0209
 
 =head1 DESCRIPTION
 
@@ -212,18 +180,28 @@ Very powefull and most exciting feature. C<Evo::Export> exports generators, that
 
 Implementation garanties that one module will get the same (cashed) generated unit (if it'l import twice or import from module that reimport the same thing), but different module will get another one
 
-  use Evo 'Evo::Comp has'; 
-  use Evo 'Evo::Comp has'; 
+  use Evo 'Evo::Class has'; 
+  use Evo 'Evo::Class has'; 
 
-C<has> was imported twice, but generated only once. If some class will do something C<export_proxy 'Evo::Comp', 'has'>, you can export that C<has> and it will be the same subroutine
+C<has> was imported twice, but generated only once. If some class will do something C<export_proxy 'Evo::Class', 'has'>, you can export that C<has> and it will be the same subroutine
 
-For example, you can use it to check, if requester component has some methods and than use it directly, if C<$self-E<gt>method()> isn't good choise
+For example, you can use it to check, if requester class has some methods and than use it directly, if C<$self-E<gt>method()> isn't good choise
 
     export_gen foo => sub ($class) {
       my $method = $class->can("name") or die "provide name";
       sub { say $method->() };
     };
 
+=head4 import
+
+By default, this method will be exported and do the stuff. If you need replace C<import> of your module, exclude it by C<use Evo '-Export *, -import'>
+
+=head4 import_all
+
+  use Evo '-Export *, -import, import_all:import';
+
+Just like C</import> but treats empty list as '*'.
+
 =head1 AUTHOR
 
 alexbyk.com
