@@ -1,5 +1,5 @@
 package Evo::Io::Handle;
-use Evo '-Comp::Out *';
+use Evo '-Class::Out *';
 
 with '-Io::Handle::Role';
 
@@ -17,7 +17,7 @@ Evo::Io::Handle
 
 =head1 VERSION
 
-version 0.0208
+version 0.0209
 
 =head1 AUTHOR
 
