@@ -1,6 +1,6 @@
 package Evo::Io::Socket;
-use Evo '-Comp::Out *';
-with ':Role', '-Io::Handle::Role';
+use Evo '-Class::Out *';
+with '::Role', '-Io::Handle::Role';
 
 1;
 
@@ -16,7 +16,7 @@ Evo::Io::Socket
 
 =head1 VERSION
 
-version 0.0208
+version 0.0209
 
 =head1 METHODS
 
