@@ -1,5 +1,5 @@
 package Evo::Lib;
-use Evo '-Export *; Carp croak; :Bare';
+use Evo '-Export *; Carp croak; ::Bare';
 use Time::HiRes qw(CLOCK_MONOTONIC);
 
 PATCH: {
@@ -39,7 +39,7 @@ Evo::Lib
 
 =head1 VERSION
 
-version 0.0208
+version 0.0209
 
 =head1 AUTHOR
 
