@@ -14,9 +14,13 @@ my $NAME = do {
 use constant SUBRE => qr/^[a-zA-Z_]\w*$/;
 sub check_subname { $_[0] =~ SUBRE }
 
-my $DEBUG = $ENV{EVO_DEBUG};
+my $DEBUG;
 sub debug { return unless $DEBUG; carp "[${\(caller)[0]}]: $_[0]"; }
 
+sub enable_debug($on) {
+  $DEBUG = $on;
+}
+enable_debug($ENV{EVO_DEBUG});
 
 # usefull?
 sub find_caller_except ($skip_ns, $i, $caller) {
@@ -84,27 +88,29 @@ sub find_subnames ($pkg, $code) {
 our $RX_PKG_NOT_FIRST = qr/[0-9A-Z_a-z]+(?:::[0-9A-Z_a-z]+)*/;
 our $RX_PKG           = qr/^[A-Z_a-z]$RX_PKG_NOT_FIRST*$/;
 
-sub _parent ($caller, $rel) {
+sub _parent ($caller) {
   my @arr = split /::/, $caller;
   pop @arr;
-  push @arr, $rel if $rel;
   join '::', @arr;
 }
 
 sub resolve_package ($caller, $pkg) {
+
   return $pkg if $pkg =~ $RX_PKG;
 
-  if ($pkg =~ /^\-($RX_PKG_NOT_FIRST)$/) {
-    return "Evo::$1";
-  }
-  elsif ($pkg =~ /^:($RX_PKG_NOT_FIRST)$/) {
-    return "${caller}::$1";
-  }
-  elsif ($pkg =~ /^::($RX_PKG_NOT_FIRST*)$/) {
-    my $resolved = _parent($caller, $1);
-    return $resolved if $resolved =~ /^$RX_PKG$/;
+  return "Evo::$1" if $pkg =~ /^\-($RX_PKG_NOT_FIRST)$/;
+
+  # parent. TODO: many //
+  if ($pkg =~ /^\/(.*)$/) {
+    my $rest   = $1;
+    my $parent = _parent($caller)
+      or croak "Can't resolve $pkg: can't find parent of caller $caller";
+
+    return "$parent$rest" if "$parent$rest" =~ /^$RX_PKG$/;
   }
 
+  return "${caller}::$1" if $pkg =~ /^::($RX_PKG_NOT_FIRST)$/;
+
   croak "Can't resolve $pkg for caller $caller";
 }
 
@@ -122,7 +128,7 @@ Evo::Lib::Bare
 
 =head1 VERSION
 
-version 0.0208
+version 0.0209
 
 =head1 DESCRIPTION
 
