@@ -1,8 +1,8 @@
 package Evo::Loop;
 use Evo '-Export *';
-use Evo ':Comp';
+use Evo '::Class';
 
-our $SINGLE = Evo::Loop::Comp::new();
+our $SINGLE = Evo::Loop::Class::new();
 
 sub loop_start : Export { $SINGLE->start(@_) }
 sub loop_stop : Export  { $SINGLE->stop(@_) }
@@ -36,7 +36,7 @@ Evo::Loop
 
 =head1 VERSION
 
-version 0.0208
+version 0.0209
 
 =head1 AUTHOR
 
