@@ -1,7 +1,7 @@
 package Evo::Net::Srv;
-use Evo '-Comp *';
+use Evo '-Class *';
 
-with ':Role', -Ee;
+with '::Role', -Ee;
 
 sub ee_events {qw(srv_accept srv_error)}
 
@@ -29,7 +29,7 @@ Evo::Net::Srv
 
 =head1 VERSION
 
-version 0.0208
+version 0.0209
 
 =head1 SYNOPSYS
 
