@@ -1,5 +1,5 @@
 package Evo::Promise::Deferred;
-use Evo '-Comp *';
+use Evo '-Class *';
 
 has 'promise', required => 1, is => 'ro';
 has 'called';
@@ -28,7 +28,7 @@ Evo::Promise::Deferred
 
 =head1 VERSION
 
-version 0.0208
+version 0.0209
 
 =head1 AUTHOR
 
